/* Regression test for NB#241257 (in progress)
 *
 * Original Author: Simon McVittie <simon.mcvittie@collabora.co.uk>
 * Changes: Cosimo Alfarano <cosimo.alfarano@collabora.co.uk>
 */


#include <glib.h>
#include <gio/gio.h>

gboolean
lookup (const gchar *mimetype,
    const gchar *expected)
{
  GIcon *icon;
  const gchar * const *names;
  guint i;

  icon = g_content_type_get_icon (g_content_type_from_mime_type (mimetype));

  if (!G_IS_THEMED_ICON (icon))
    {
      g_warning ("Maemo is Unix, we should get a themed icon here");
      return FALSE;
    }

  if (expected != NULL)
    {
      g_message ("====== MIME type %s", mimetype);
      g_message ("expecting        %s", expected);
    }

  names = g_themed_icon_get_names (G_THEMED_ICON (icon));

  for (i = 0; names != NULL && names[i] != NULL; i++)
    {
      g_message ("%s %s",
        i == 0 ? "(most preferred)"
	       : "                ",
        names[i]);
    }

  if (expected != NULL)
    {
      g_assert_cmpstr (names[0], ==, expected);
    }

  return TRUE;
}

int
main (int argc, char **argv)
{
  int i;

  g_type_init ();

  if (argc < 2)
    {
      /* no arguments: run as a regression test */

      lookup ("application/pdf",                "icon-m-content-pdf");
      lookup ("application/vnd.ms-powerpoint",  "icon-m-content-powerpoint");
      lookup ("application/vnd.ms-excel",       "icon-m-content-excel");
      lookup ("application/msword",             "icon-m-content-word");
      lookup ("application/msword-template",    "icon-m-content-word");
      lookup ("application/x-ms-dos-executable", "icon-m-content-application");
      /* See debian/meego-icons maps in shared-mime-info */
      lookup ("application/pgp-signature",      "icon-m-content-document");
      lookup ("application/x-font-ttf",         "icon-m-content-file-unknown");
      lookup ("application/x-deb",              "icon-m-content-debian");
      /* it should be m-content-package, but such icon does not exist
      lookup ("application/x-rpm",              "icon-m-content-debian");
      */
      lookup ("audio/webm",                     "icon-m-content-audio");
      lookup ("audio/x-flac",                   "icon-m-content-audio");
      lookup ("audio/ogg",                    "icon-m-content-audio");
      lookup ("audio/x-s3m",                    "icon-m-content-audio");
      lookup ("image/jpeg",                     "icon-m-content-image");
      lookup ("image/png",                      "icon-m-content-image");
      lookup ("image/x-xwindowdump",            "icon-m-content-image");
      lookup ("text/html",                      "icon-m-content-document");
      lookup ("text/plain",                     "icon-m-content-document");
      /* It does not exist in the XML desc
      lookup ("text/x-cobol",                   "icon-m-content-document");
      */
      lookup ("application/x-shellscript",      "icon-m-content-application");
      lookup ("message/rfc822",                 "icon-m-content-document");
      lookup ("video/3gpp",                     "icon-m-content-video");
      lookup ("video/ogg",                      "icon-m-content-video");
      lookup ("video/mpeg",                     "icon-m-content-video");
      lookup ("video/mp4",                      "icon-m-content-video");
      lookup ("video/webm",                     "icon-m-content-video");
      lookup ("video/x-flv",                    "icon-m-content-video");
      lookup ("video/x-matroska",               "icon-m-content-video");
      lookup ("application/vnd.oasis.opendocument.text", "icon-m-content-document");
      lookup ("application/docbook+xml",        "icon-m-content-document");
      lookup ("application/x-gnumeric",         "icon-m-content-document");
      lookup ("application/octet-stream",       "icon-m-content-file-unknown");
    }
  else
    {
      /* with arguments: do a manual test for each */
      for (i = 1; i < argc; i++)
        {
          lookup (argv[i], NULL);
        }
    }

  return 0;
}
